/*
 * Programa: BX_Client02_Ver1.java
 * Objectiu: Programa que efectua la creació d'una BD buida amb el nom
             indicat com argument en la crida d'execució del programa
 * Autor...: Isidre Guixà
 */
package org.milaifontanals.baseX;
import org.basex.api.client.ClientSession;
import org.basex.core.BaseXException;
import java.io.IOException;

public final class BX_Client02_Ver1 {
  // Amaguem el constructor per defecte. */
  private BX_Client02_Ver1() { }

  /* El programa principal admet com a paràmetre el nom de la base de
   * dades a crear. Cal comprovar la no existència d'una base de dades
   * amb idèntic nom, doncs en la versió actual (7.1) de BaseX, la
   * creació d'una base de dades no comprova l'existència d'una base de
   * dades amb igual nom i sobreescriu la base de dades que pogués existir.
   */
  public static void main(String[] args) {
    if (args.length!=1) {
      System.out.println("Cal indicar el nom de la BD a crear");
      System.exit(1);
    }
    ClientSession session=null;
    try {
      // Obrir sessió:
      session = new ClientSession("10.2.238.132", 1984, "admin", "admin");
      // Procedim a comprovar si la base de dades existeix, tot obrint-la:
      boolean existeix=true;
      try {
        session.execute("open "+args[0]);
      } 
      catch (BaseXException bxe) {
          existeix=false;
      }
      // Actuem segons la BD existeix o no existeix
      if (existeix) {
        System.out.println("Ja existeix una BD amb aquest nom.");
      }
      else {
        System.out.println("No existeix cap BD amb aquest nom. Procedim...");
//        session.create(args[0],new ByteArrayInputStream("".getBytes()));
        // El mètode "create" obliga a introduir un primer document,
        // com a segon paràmetre del tipus InputStream.
        // Com que volíem crear una base de dades buida, li hem passat
        // un document buit, construït amb "".getBytes()
        
        // Forma alternativa de crear una base de dades buida:
         session.execute ("create database "+args[0]);

        // Per obtenir informació de la creació:
        System.out.println(session.info());
      }
    }
    catch (IOException ioe) {
      ioe.printStackTrace();
    }
    finally { /* Tanquem sessió en qualsevol cas */
      try {
          if(session != null) session.close();
      }
      catch(IOException ioe) {
          ioe.printStackTrace();
      }
    }
  }
}